@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.0700';
+our $VERSION = '0.0800';
 
 use Moo;
 use MIDI::Simple;
@@ -25,8 +25,6 @@ sub BUILD {
     $self->score->noop( 'c' . $self->channel, 'V' . $self->volume );
     $self->score->set_tempo( int( 60_000_000 / $self->bpm ) );
 
-    $self->score->patch_change( $self->channel, $self->patch );
-
     $self->score->control_change( $self->channel, 91, $self->reverb ) if $self->reverb;
     $self->score->control_change( $self->channel, 93, $self->chorus ) if $self->chorus;
     $self->score->control_change( $self->channel, 10, $self->pan ) if $self->pan;
@@ -34,7 +32,6 @@ sub BUILD {
 
 
 has channel   => ( is => 'ro', default => sub { 9 } );
-has patch     => ( is => 'ro', default => sub { 0 } );
 has volume    => ( is => 'ro', default => sub { 100 } );
 has bpm       => ( is => 'ro', default => sub { 120 } );
 has reverb    => ( is => 'ro', default => sub { 0 } );
@@ -130,7 +127,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.0700
+version 0.0800
 
 =head1 SYNOPSIS
 
@@ -140,7 +137,6 @@ version 0.0700
     bpm       => 100,
     signature => '3/4',
     bars      => 32,
-    patch     => 26, # TR808
  );
  $d->count_in(1);
  $d->note( $d->quarter, $d->open_hh, $_ % 2 ? $d->kick : $d->snare )
@@ -171,10 +167,6 @@ Default: 9
 
 Default: 100
 
-=head2 patch
-
-Default: 0
-
 =head2 bpm
 
 Default: 120
